package Table::Denormalized::Column;
use strict;
use vars qw($VERSION);
$VERSION = '0.06';

use base 'Class::Accessor';

=head1 NAME

Table::Denormalized::Column - Encapsulate information for a SQL column

=head1 SYNOPSIS

=head1 ABSTRACT

This module trivially encapsulates the information about a column
in an SQL database as the pair of name and type.

=cut

__PACKAGE__->mk_accessors(qw(name type));

=head2 C<< name >>

Accessor for the column name

=head2 C<< type >>

Accessor for the column type

=head2 C<< $column->as_sql >>

Returns an SQL fragment suitable to be used in an
C<ALTER TABLE ADD COLUMN %s> statement.

=cut

sub as_sql {
  my $self = shift;
  return sprintf "%s %s", $self->name, $self->type
};

1;

=head1 AUTHOR

Max Maischein, E<lt>corion@cpan.orgE<gt>

=head1 SEE ALSO

L<DBI>, L<Class::DBI>
