#!perl -w

# Stolen from ChrisDolan on use.perl.org
# http://use.perl.org/comments.pl?sid=29264&cid=44309
# Modified to also check the Changes file to
# have an entry for the version being released

use warnings;
use strict;
use File::Find;
use Test::More;
BEGIN {
    eval 'use File::Slurp; 1';
    if ($@) {
        plan skip_all => "File::Slurp needed for testing";
        exit 0;
    };
};

plan 'no_plan';

my %versions;

sub collect {
    return if (! m{blib/script/}xms && ! m{\.pm \z}xms);

    my $file = $_;

    my $content = read_file($file);

    # only look at perl scripts, not sh scripts
    return if (m{blib/script/}xms && $content !~ m/\A \#![^\r\n]+?perl/xms);

    my @version_lines = $content =~ m/ ( [^\n]* \$VERSION \s* = [^=] [^\r\n]* ) /gxms;
    if (@version_lines == 0) {
        fail($file);
	diag "$file has no version.";
    }
    $versions{ $file } = \@version_lines;
}

my $max_version;
sub check {
    my ($versions) = @_;
    for my $file (keys %$versions) {
        for (@{ $versions{ $file }}) {
            if (! defined $max_version or $max_version lt $_) {
	        $max_version = $_;
	    };
        };
    };
    for my $file (keys %$versions) {
        for my $line (@{ $versions{ $file }}) {
            is($line, $max_version, $file);
        }
    };
};

find({wanted => \&collect, no_chdir => 1}, 'blib');

if (! keys %versions) {
    fail('Failed to find any files with $VERSION');
} else {
    check(\%versions);
};

# Now also check whether the Changes file has something
# matching our purported version:
my $no = eval "my \$VERSION; $max_version";
my @entries = grep /\Q$no\E/, read_file( 'Changes' );
isn't \@entries, [], "Found entry mentioning version $no in Changes";
