#!/usr/bin/perl -w
use strict;
use Test::More tests => 13;
use Data::Dumper qw(Dumper);
use FFRIndexed;

$|++;
use_ok 'Table::Denormalized::ColumnRefiner';

my $idx = FFRIndexed->new( create_if_needed => 1,  );
END { undef $idx; unlink "$0.sqlite" }

my @dirs = do { local *DIR;
  opendir DIR, '\\\\aliens\\media\\mp3';
  map { URI::file->new( "\\\\aliens\\media\\mp3\\$_" ) } grep { /^J/i } readdir DIR
};

if (! @dirs) {
    SKIP: { skip "MP3 tests skipped, because your infrastructure does not match mine", 12 };
    exit;
};

$idx->scan( $_ )
    for @dirs;

my $table = $idx->table;

my $res = $idx->query([]); # sluurp
isa_ok $res, 'Table::Denormalized::ResultSet';

my $refiner = Table::Denormalized::ColumnRefiner->new(table => $table, columns => [qw(album artist mime_type)]);
isa_ok( $refiner, 'Table::Denormalized::ColumnRefiner' );

my @refinements = map { $_->column } $refiner->refinements($res->query);
is_deeply( \@refinements, [qw[album artist mime_type]], "We get three possible refinements");

# Actually check _all_ combinations.

my $old_size = @$res;

$res = $idx->query( $res->refine( { 'artist' => 'Jamiroquai' } ));
cmp_ok( scalar @$res, ">", 0, "We actually got rows left");
cmp_ok( scalar @$res, "<", $old_size, "Refining by 'Jamiroquai' actually reduced the result set");

@refinements = map { $_->column } $refiner->refinements($res->query);
is_deeply( \@refinements, [qw[album mime_type]], "Since we fixed the artist, it doesn't show up anymore");

# And refine some more, by only allowing mpeg files :
$old_size = @$res;
$res = $idx->query( $res->refine( { 'mime_type' => 'audio/mpeg' } ));
cmp_ok( scalar @$res, ">", 0, "We actually got rows left");
cmp_ok( scalar @$res, "<", $old_size, "Refining by 'audio/mpeg' actually reduced the result set");

@refinements = map { $_->column } $refiner->refinements($res->query);
is_deeply( \@refinements, [qw[album]], "Since we fixed the mime type as well, it doesn't show up anymore either");

$old_size = @$res;
$res = $idx->query( $res->refine( { 'album' => 'The Return of the Space Cowboy' } ));
cmp_ok( scalar @$res, ">", 0, "We actually got rows left");
cmp_ok( scalar @$res, "<", $old_size, "Refining by 'The Return of the Space Cowboy' actually reduced the result set");
@refinements = map { $_->column } $refiner->refinements($res->query);
is_deeply( \@refinements, [], "Nothing to fix in the query anymore");
