#!/usr/bin/perl -w
use strict;
use Test::More tests => 5;
use Data::Dumper qw(Dumper);
use FFRIndexed;

$|++;
use_ok 'Table::ColumnRefinement';

my $idx = FFRIndexed->new( create_if_needed => 1,  );
END { undef $idx; unlink "$0.sqlite" }

my @dirs;
{ 
  opendir my $dh, '\\\\aliens\\media\\mp3';
  @dirs = grep {/^J/i} readdir $dh;
  $idx->scan( map { URI::file->new( "\\\\aliens\\media\\mp3\\$_" ) } @dirs );
};

if (! @dirs) {
    SKIP: {
        skip "Your infrastructure doesn't match mine", 4;
    };
    exit
};

my $res = $idx->query([]); # sluurp

my $table = $idx->table;

my @refinements;
for my $column (qw(artist album), 'mime_type') {
    my $ref = Table::ColumnRefinement->new($table,$column,$res);
    next if $ref->is_trivial;

    push @refinements, $column;
};
is_deeply( [sort @refinements], [qw[album artist mime_type]], "We get three possible refinements");

my $old_size = @$res;

@refinements = ();
# Now, refine the results by 'artist = "Jamiroquai"' :
$res = $idx->query( $res->refine( { 'artist' => 'Jamiroquai' } ));
cmp_ok( scalar @$res, "<", $old_size, "Refining by 'Jamiroquai' actually reduced the result set");

for my $column (qw(artist album), 'mime_type') {
    my $ref = Table::ColumnRefinement->new($table,$column,$res);
    next if $ref->is_trivial;
        
    push @refinements, $column;
};
is_deeply( [sort @refinements], [qw[album mime_type]], "Since we fixed the artist, it doesn't show up anymore");

# And refine some more, by only allowing mpeg files :
@refinements = ();
$res = $idx->query( $res->refine( { 'mime_type' => 'audio/mpeg' } ));
for my $column (qw(artist album), 'mime_type') {
    my $ref = Table::ColumnRefinement->new($table,$column,$res);
    next if $ref->is_trivial;

    push @refinements, $column;
};
is_deeply( [sort @refinements], [qw[album]], "Since we fixed the mime type as well, it doesn't show up anymore either");
