#!/usr/bin/perl -w
use strict;
use Test::More tests => 3;
use File::Spec;

use_ok 'FFRIndexed';

my $dbfile = ":memory:";

if (-f $dbfile) {
    diag "Removing leftover database '$dbfile'";
    unlink $dbfile
        or diag "Couldn't remove $dbfile: $!";;
};
my $idx = FFRIndexed->new(
    dsn => "dbi:SQLite:dbname=$dbfile"
);

$idx->scan('t/');

my @files;
{
  opendir my $dh, "t"
    or die "Couldn't read t/: $!";
  @files = sort grep { -f } map {File::Spec->rel2abs( $_, 't/' )} readdir $dh;
};

my $res = $idx->query([]);
is_deeply [ sort grep { !/CVS/} map {$_->filename} @$res ], \@files, "We found all files";

$res = $idx->query( { uri => { like => '%.t' } });
is_deeply [ sort map {$_->filename} @$res ], [grep {/\.t$/i} @files], "We found all files";

undef $idx;
